#[repr(u8)]pub enum DisablePulseSkip {
IDLE = 0,
NOT_IDLE = 1,
}Variants
IDLE = 0
DCDC will be idle to save current dissipation when the duty cycle get to the low limit which is set by NEGLIMIT_IN.
NOT_IDLE = 1
DCDC will keep working with the low limited duty cycle NEGLIMIT_IN.
Implementations